#
# spec file for package azure-cli-telemetry
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons %{primary_python}
%else
%define pythons python311
%endif
%global _sitelibdir %{%{pythons}_sitelib}

Name:           azure-cli-telemetry
Version:        1.1.0
Release:        4.1
Summary:        Microsoft Azure CLI Telemetry Package
License:        MIT
Group:          System/Management
URL:            https://github.com/Azure/azure-cli
Source:         https://files.pythonhosted.org/packages/source/a/azure-cli-telemetry/azure-cli-telemetry-%{version}.tar.gz
Patch:          act_relax-portalocker.patch
BuildRequires:  %{pythons}-azure-nspkg >= 3.0.0
BuildRequires:  %{pythons}-pip
BuildRequires:  %{pythons}-setuptools
BuildRequires:  %{pythons}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       %{pythons}-applicationinsights < 0.12
Requires:       %{pythons}-applicationinsights >= 0.11.1
Requires:       %{pythons}-azure-nspkg >= 3.0.0
Requires:       %{pythons}-portalocker < 4.0
Requires:       %{pythons}-portalocker >= 1.6
Requires:       azure-cli-core
Conflicts:      azure-cli < 2.0.0

BuildArch:      noarch

%description
Microsoft Azure CLI Telemetry Package

This is the Microsoft Azure CLI Telemetry package. It is not intended to be installed directly by the end user.

This package includes:
1. Support API for Azure CLI to gather telemetry.
2. Telemetry upload process.

%prep
%setup -q -n azure-cli-telemetry-%{version}
%patch -P0 -p1

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}%{_sitelibdir}

%files
%defattr(-,root,root,-)
%doc HISTORY.rst README.rst
%license LICENSE.txt
%dir %{_sitelibdir}/azure/cli
%{_sitelibdir}/azure/cli/telemetry
%{_sitelibdir}/azure_cli_telemetry-*.dist-info

%changelog
* Mon Nov 25 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to relax python-portalocker version dependency in setup.py
  + act_relax-portalocker.patch
- Add %%{_sitelibdir}/azure/cli directory in %%files section
- Drop superflouos azure-cli-core from BuildDepends
- Drop extra LICENSE.txt as upstream now ships its own
- Relax python-portalocker version dependency in Requires
* Wed May 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add azure-cli-core to BuildRequires and Requires
- Remove azure-cli-nspkg from BuildRequires and Requires
- Remove deletion of azure-cli namespace files
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Use primary Python version on Tumbleweed
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
* Mon Aug 14 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.1.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Fri Sep 16 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.8
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Thu Aug  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.7
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Jun 27 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add missing python-rpm-macros package to BuildRequires
* Wed Sep  2 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.6
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Thu Oct 24 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.4
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Drop patch to relax version requires in setup.py, it's
  not required as the dependencies are managed by RPM
  + act_relax-requires-versions.patch
- Update Requires from setup.py
* Tue Jun  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove unneccesary %%python_expand prefix from %%fdupes call
* Tue Apr 16 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.0.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Bump minimum version for Python Azure SDK namespace
  packages to 3.0.0 in BuildRequires and Requires
- Remove python3-devel package from BuildRequires
- Remove unzip package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
* Mon Oct  1 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.0.0
- Add patch to relax version numbers in install_requires
  + act_relax-requires-versions.patch
